<?php

//Setup -------------
if (! function_exists('bonyo_setup')) :
function bonyo_setup() {

	load_theme_textdomain('bonyo', get_template_directory() . '/languages');

	add_theme_support('post-thumbnails');
	add_theme_support('html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption'));
	add_theme_support("title-tag");
	add_theme_support('automatic-feed-links');

	//Content Width
	$GLOBALS['content_width'] = apply_filters('bny_content_width', 624);
}
endif;
add_action('after_setup_theme', 'bonyo_setup');


	
//Load Styles and Scripts -------------
function bny_enq_style_scripts() {

	//style of theme
	wp_enqueue_style('theme-style', get_stylesheet_directory_uri() . '/style.css');

	//Font Awesome 4.7.0
	wp_enqueue_style('fontawesome-style', get_stylesheet_directory_uri() . '/fonts/font-awesome-4.7.0/css/font-awesome.min.css');

	//Comment Reply
	if (is_singular() && comments_open()) {
		wp_enqueue_script('comment-reply');
	}

	//Disable Style for block editor (Gutenberg)
	wp_dequeue_style('wp-block-library');

}
add_action('wp_enqueue_scripts', 'bny_enq_style_scripts');

//replace style meta tag --------------
function bny_css_async($tag) {
	if (!strpos($tag, 'fontawesome-style') === false) {
		$awesome = get_template_directory_uri() . '/fonts/font-awesome-4.7.0/css/font-awesome.min.css';
		$tag = str_replace('media=\'all\' />', 'media="none" onload="if(media!=\'all\')media=\'all\'"><noscript><link rel="stylesheet" href="' . $awesome . '"></noscript>', $tag);
	}
	return $tag;
}
add_filter('style_loader_tag', 'bny_css_async');



//Nav Menu custom class ---------------
class bny_nav_walker extends Walker_Nav_Menu {
	function start_lvl(&$output, $depth = 0, $args = array()) {
		$output .= '<input class="menu-toggle" type="checkbox" /><ul class="sub-menu">';
	}
	function end_lvl(&$output, $depth = 0, $args = array()) {
		$output .= '</ul>';
	}
}



//Sidebar Widget -------------
if (!function_exists('bonyo_widgets_init')):
function bonyo_widgets_init() {
	register_sidebar(array(
		'name'          => esc_html__('Sidebar', 'bonyo'),
		'id'            => 'sidebar-1',
		'description'   => esc_html__('Add widgets here.', 'bonyo'),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));
}
endif;
add_action('widgets_init', 'bonyo_widgets_init');



//Search widget form ---------------
function bny_search_form($form) {
	$form = '<form role="search" method="get" class="search-form" action="' . esc_url(home_url('/')) . '">
	<div>
		<input type="search" class="search-field" placeholder="" value="' . get_search_query() . '" name="s" />
		<input type="submit" class="search-submit" value="&#xf002;" />
	</div>
	</form>';
	return $form;
}
add_filter('get_search_form', 'bny_search_form');



//Read more (excerpt) ---------------
function bny_excerpt_more($excerpt) { 
	return $excerpt. ' <div class="read-more"><div class="more-button">' . __('Read more', 'bonyo') . '</div>'; 
}
add_filter('get_the_excerpt', 'bny_excerpt_more');





